@@ -182,22 +182,22 @@
       
       (define (redraw-graph)
 	(let* ((wn (GDK_WINDOW (gtk_widget_get_window scan-pane)))
-	       (cr (gdk_cairo_create wn)))
+	       (cr (make_cairo wn)))
 	  (set! bounds (draw-axes scan-pane gc "scanned synthesis" 0.0 1.0 -10.0 10.0 x-axis-in-seconds show-all-axes cr))
 	  (set! ax0 (+ (car bounds) 4))
 	  (set! ax1 (caddr bounds))
 	  (set! ay1 (cadr bounds))
 	  (set! ay0 (cadddr bounds))
 	  (draw-graph cr)
-	  (cairo_destroy cr)))
+	  (free_cairo cr)))
       
       (define (tick-synthesis n)
 	;; background process
 	(vibrating-uniform-circular-string size gx0 gx1 gx2 mass xspring damp)
 	(let* ((wn (GDK_WINDOW (gtk_widget_get_window scan-pane)))
-	       (cr (gdk_cairo_create wn)))
+	       (cr (make_cairo wn)))
 	  (draw-graph cr)
-	  (cairo_destroy cr))
+	  (free_cairo cr))
 	#t)
       
       (define (stop-synthesis)
@@ -408,31 +408,30 @@
 ;;; adds a label to the status-area area showing the current free space 
   
   (define show-disk-space
-    (let ((labelled-snds ()))
-      
-      (define (kmg num)
-	(cond ((<= num 0)      (copy "disk full!"))
-	      ((<= num 1024)   (format #f "space: ~10DK" num))
-	      ((> num 1048576) (format #f "space: ~6,3FG" (/ num (* 1024.0 1024.0))))
-	      (else            (format #f "space: ~6,3FM" (/ num 1024.0)))))
-      
-      (define (show-label data)
-	(if (sound? (car data))
-	    (let ((space (kmg (disk-kspace (file-name (car data))))))
-	      (gtk_label_set_text (GTK_LABEL (cadr data)) space)
-	      (g_timeout_add 10000 show-label data) ; every 10 seconds recheck space
-	      0)))
-      
-      (define (find-if pred lst)
-	(cond ((null? lst) #f)
-	      ((pred (car lst)) (car lst))
-	      (else (find-if pred (cdr lst)))))
-      
+    (let ((labelled-snds ())
+	  
+	  (kmg (lambda (num)
+		 (cond ((<= num 0)      (copy "disk full!"))
+		       ((<= num 1024)   (format #f "space: ~10DK" num))
+		       ((> num 1048576) (format #f "space: ~6,3FG" (/ num (* 1024.0 1024.0))))
+		       (else            (format #f "space: ~6,3FM" (/ num 1024.0))))))
+	  
+	  (show-label (lambda (data)
+			(if (sound? (car data))
+			    (let ((space (kmg (disk-kspace (file-name (car data))))))
+			      (gtk_label_set_text (GTK_LABEL (cadr data)) space)
+			      (g_timeout_add 10000 show-label data) ; every 10 seconds recheck space
+			      0)))))
       (lambda (hook)
 	;; (show-disk-space snd) adds a label to snd's status-area area showing the current free space (for use with after-open-hook)
 	
 	(let* ((snd (hook 'snd))
-	       (previous-label (find-if (lambda (n) (equal? (car n) snd)) labelled-snds)))
+	       (previous-label (let find-if ((pred (lambda (n)
+						     (equal? (car n) snd)))
+					     (lst labelled-snds))
+				 (cond ((null? lst) #f)
+				       ((pred (car lst)) (car lst))
+				       (else (find-if pred (cdr lst)))))))
 	  (if (not previous-label)
 	      (if (not snd)
 		  (snd-error "no sound found for disk space label")
@@ -473,7 +472,7 @@
   
   (define snd-clock-icon
     (lambda (snd hour)
-      (let ((cr (gdk_cairo_create (GDK_WINDOW (gtk_widget_get_window ((sound-widgets snd) 8))))))
+      (let ((cr (make_cairo (GDK_WINDOW (gtk_widget_get_window ((sound-widgets snd) 8))))))
 	(let ((bg (color->list *basic-color*)))
 	  (cairo_set_source_rgb cr (car bg) (cadr bg) (caddr bg)))
 	(cairo_rectangle cr 0 0 16 16) ; icon bg
@@ -487,7 +486,7 @@
 	(cairo_line_to cr (+ 8 (* 7 (sin (* hour (/ 3.1416 6.0)))))
 		       (- 8 (* 7 (cos (* hour (/ 3.1416 6.0))))))
 	(cairo_stroke cr)
-	(cairo_destroy cr))))
+	(free_cairo cr))))
   
   
 #|  
@@ -495,7 +494,7 @@
   
   (define (snd-happy-face snd progress)
     (let* ((window (GDK_WINDOW (gtk_widget_get_window ((sound-widgets snd) 8))))
-	   (cr (gdk_cairo_create window))
+	   (cr (make_cairo window))
 	   (fc (list 1.0 progress 0.0)))
       (let ((bg (color->list *basic-color*)))
         ;; overall background
@@ -527,7 +526,7 @@
 	      (cairo_arc cr 8 8 5 (* 1/16 pi) (* 15/16 pi))))
       (cairo_stroke cr)
       
-      (cairo_destroy cr)))
+      (free_cairo cr)))
 |#
   
   
@@ -552,19 +551,17 @@
   
   (define select-file
     
-    (let ((file-selector-dialogs ()))
-      ;; (list (list widget inuse func title help) ...)
-      
-      (define (find-free-dialog ds)
-	(and (pair? ds)
-	     (pair? (car ds))
-	     (pair? (cdar ds))
-	     (if (cadar ds)
-		 (find-free-dialog (cdr ds))
-		 (begin
-		   (set! ((car ds) 1) #t)
-		   (caar ds)))))
-
+    (letrec ((file-selector-dialogs ())   ; (list (list widget inuse func title help) ...)
+	     (find-free-dialog 
+	      (lambda (ds)
+		(and (pair? ds)
+		     (pair? (car ds))
+		     (pair? (cdar ds))
+		     (if (cadar ds)
+			 (find-free-dialog (cdr ds))
+			 (begin
+			   (set! ((car ds) 1) #t)
+			   (caar ds)))))))
       (lambda args
 	;; (file-select func title dir filter help)
 	(let* ((func (and (pair? args) (args 0)))
@@ -583,7 +580,7 @@
 	      (func (gtk_file_chooser_get_filename (GTK_FILE_CHOOSER dialog))))
 	  (gtk_widget_hide (GTK_WIDGET dialog))))))
   
-  ;;(select-file (lambda (n) (snd-print n)))
+  ;; ((*gtk* 'select-file) (lambda (n) (snd-print n)))
   
   
   
@@ -622,7 +619,7 @@
 	   (win (GDK_WINDOW (gtk_widget_get_window meter))))
       
       ;; this is too slow -- can we save the plate? (also if just 1 meter, put pivot higher?)
-      (let ((cr (gdk_cairo_create win)))
+      (let ((cr (make_cairo win)))
 	
 	;; put our origin at the meter pivot point scaled (as a square so the dial remains circular) to 0..1
 	(cairo_translate cr (* 0.5 width) (+ (* 0.5 width) (* 0.2 height)))
@@ -704,7 +701,7 @@
 		  (cairo_arc cr 0 0 (- 0.5 (/ 3.0 width))  (+ (* 5 (/ pi 4)) (max 0.0 (- redx bubble-size))) (+ (* 5 (/ pi 4)) redx))
 		  (cairo_stroke cr)))))
 	
-	(cairo_destroy cr))))
+	(free_cairo cr))))
   
   
   (define (with-level-meters n)
@@ -762,7 +759,6 @@
   (define (make-variables-dialog)
     (set! variables-dialog (gtk_dialog_new))
     (gtk_window_set_title (GTK_WINDOW variables-dialog) "Variables")
-    (gtk_container_set_border_width (GTK_CONTAINER variables-dialog) 10)
     (gtk_window_set_default_size (GTK_WINDOW variables-dialog) -1 -1)
     (gtk_window_set_resizable (GTK_WINDOW variables-dialog) #t)
     (gtk_widget_realize variables-dialog)
@@ -832,45 +828,45 @@
 	     (list (sound->integer snd) (channel-data snd 0))))
 	  (else #f)))))
   
-  (define (variable-display var widget)
-    
-    (define (force-update wid)
-      (gdk_window_invalidate_rect (GDK_WINDOW (gtk_widget_get_window (GTK_WIDGET wid))) (list 'GdkRectangle_ 0) #t)
-      (gdk_window_process_updates (GDK_WINDOW (gtk_widget_get_window (GTK_WIDGET wid))) #t))
-    
-    (define (widget? w) (and (pair? w) (= (length w) 2) (eq? (car w) 'GtkWidget_)))
-    
-    ;; (let ((wid1 (make-variable-display "do-loop" "i*1" 'spectrum))) (variable-display 0.1 wid1))
-    
-    (if (widget? widget)
-	(if (GTK_IS_LABEL widget)
-	    (begin
-	      (gtk_label_set_text (GTK_LABEL widget) (object->string var))
-	      (force-update widget)))
-	
-	(when (and (pair? widget)
-		   (or (number? (car widget))
-		       (sound? (car widget))))
-	  ;; graph/spectrum -- does this need an explicit update?
-	  (let ((snd (car widget))
-		(data (cadr widget)))
-	    (let ((len (length data))
-		  (loc (cursor snd 0)))
-	      (set! (data loc) var)
-	      (if (time-graph? snd) (update-time-graph snd))
-	      (if (transform-graph? snd) (update-transform-graph snd))
-	      (set! (cursor snd 0) (if (= (+ loc 1) len) 0 (+ loc 1))))
-	    (if (GTK_IS_PROGRESS_BAR (car widget))
-		;; "thermometer"
-		(let ((y0 (cadr widget))
-		      (y1 (caddr widget)))
-		  ;; (define wid (make-variable-display "do-loop" "i*2" 'scale))
-		  (gtk_progress_bar_set_fraction 
-		   (GTK_PROGRESS_BAR (car widget))
-		   (max 0.0 (min 1.0 (/ (- var y0) (- y1 y0))))))))))
-    var)
+  (define variable-display 
+    (let ((force-update (lambda (wid)
+			  (gdk_window_invalidate_rect (GDK_WINDOW (gtk_widget_get_window (GTK_WIDGET wid))) (list 'GdkRectangle_ 0) #t)
+			  ))
+	  (widget? (lambda (w) 
+		     (and (pair? w) 
+			  (= (length w) 2)
+			  (eq? (car w) 'GtkWidget_)))))
+      ;; (let ((wid1 (make-variable-display "do-loop" "i*1" 'spectrum))) (variable-display 0.1 wid1))
+      (lambda (var widget)
+	(if (widget? widget)
+	    (if (GTK_IS_LABEL widget)
+		(begin
+		  (gtk_label_set_text (GTK_LABEL widget) (object->string var))
+		  (force-update widget)))
+	    
+	    (when (and (pair? widget)
+		       (or (number? (car widget))
+			   (sound? (car widget))))
+	      ;; graph/spectrum -- does this need an explicit update?
+	      (let ((snd (car widget))
+		    (data (cadr widget)))
+		(let ((len (length data))
+		      (loc (cursor snd 0)))
+		  (set! (data loc) var)
+		  (if (time-graph? snd) (update-time-graph snd))
+		  (if (transform-graph? snd) (update-transform-graph snd))
+		  (set! (cursor snd 0) (if (= (+ loc 1) len) 0 (+ loc 1))))
+		(if (GTK_IS_PROGRESS_BAR (car widget))
+		    ;; "thermometer"
+		    (let ((y0 (cadr widget))
+			  (y1 (caddr widget)))
+		      ;; (define wid (make-variable-display "do-loop" "i*2" 'scale))
+		      (gtk_progress_bar_set_fraction 
+		       (GTK_PROGRESS_BAR (car widget))
+		       (max 0.0 (min 1.0 (/ (- var y0) (- y1 y0))))))))))
+	var)))
 
   (define (notebook-with-top-tabs)
     (gtk_notebook_set_tab_pos (GTK_NOTEBOOK ((main-widgets) 5)) GTK_POS_TOP))
 
-  ) ; *gtk*
\ No newline at end of file
+  ) ; *gtk*
